@@ -26,6 +26,7 @@
 enum
 {
   PROP_0,
+  PROP_BAIZE_COLOR,
   PROP_CARD_OVERHANG,
   PROP_CARD_SLOT_RATIO,
   PROP_CARD_STEP,
@@ -38,9 +39,6 @@ enum
   PROP_FOCUS_LINE_WIDTH,
   PROP_FOCUS_PADDING,
   PROP_INTERIOR_FOCUS,
-#ifndef HAVE_CLUTTER
-  PROP_PIXBUF_DRAWING,
-#endif
   PROP_RTL,
   PROP_SELECTION_COLOR,
   PROP_SHOW_TOOLTIPS,
@@ -61,11 +59,8 @@ ar_style_init (ArStyle *style)
 
   priv = style->priv = G_TYPE_INSTANCE_GET_PRIVATE (style, AR_TYPE_STYLE, ArStylePrivate);
 
-#ifdef HAVE_CLUTTER
-  _ar_clutter_color_from_gdk_color (&priv->selection_color, &default_selection_color);
-#else
   priv->selection_color = default_selection_color;
-#endif
+  priv->baize_color = default_baize_color;
 
   priv->card_slot_ratio = DEFAULT_CARD_SLOT_RATIO;
   priv->card_overhang = DEFAULT_CARD_OVERHANG;
@@ -85,8 +80,6 @@ ar_style_init (ArStyle *style)
   priv->enable_tooltips = DEFAULT_SHOW_TOOLTIPS;
   priv->enable_status_messages = DEFAULT_SHOW_STATUS_MESSAGES;
 
-#ifndef HAVE_CLUTTER
-
 #ifdef HAVE_HILDON
   priv->pixbuf_drawing = FALSE;
 #else
@@ -103,8 +96,6 @@ ar_style_init (ArStyle *style)
   _games_debug_print (GAMES_DEBUG_GAME_STYLE,
                       "[ArStyle %p] Using %s drawing\n",
                       style, priv->pixbuf_drawing ? "pixbuf" : "pixmap");
-
-#endif /* !HAVE_CLUTTER */
 }
 
 static void
@@ -130,6 +121,10 @@ ar_style_get_property (GObject    *object,
   ArStylePrivate *priv = style->priv;
 
   switch (property_id) {
+    case PROP_BAIZE_COLOR:
+      g_value_set_boxed (value, &priv->baize_color);
+      break;
+
     case PROP_CARD_OVERHANG:
       g_value_set_double (value, ar_style_get_card_overhang (style));
       break;
@@ -178,12 +173,6 @@ ar_style_get_property (GObject    *object,
       g_value_set_boolean (value, ar_style_get_interior_focus (style));
       break;
 
-#ifndef HAVE_CLUTTER
-    case PROP_PIXBUF_DRAWING:
-      g_value_set_boolean (value, ar_style_get_pixbuf_drawing (style));
-      break;
-#endif
-
     case PROP_RTL:
       g_value_set_boolean (value, ar_style_get_rtl (style));
       break;
@@ -219,6 +208,17 @@ ar_style_set_property (GObject      *object,
   ArStylePrivate *priv = style->priv;
 
   switch (property_id) {
+    case PROP_BAIZE_COLOR: {
+      GdkColor *color;
+
+      if ((color = g_value_get_boxed (value)) != NULL) {
+        priv->baize_color = *color;
+      } else {
+        priv->baize_color = default_baize_color;
+      }
+      break;
+    }
+
     case PROP_CARD_OVERHANG:
       priv->card_overhang = g_value_get_double (value);
       break;
@@ -263,25 +263,11 @@ ar_style_set_property (GObject      *object,
       priv->interior_focus = g_value_get_boolean (value) != FALSE;
       break;
 
-#ifndef HAVE_CLUTTER
-    case PROP_PIXBUF_DRAWING:
-      priv->pixbuf_drawing = g_value_get_boolean (value) != FALSE;
-#endif
-
     case PROP_RTL:
       priv->rtl = g_value_get_boolean (value) != FALSE;
       break;
 
     case PROP_SELECTION_COLOR: {
-#ifdef HAVE_CLUTTER
-      ClutterColor *color;
-
-      if ((color = g_value_get_boxed (value)) != NULL) {
-        priv->selection_color = *color;
-      } else {
-        _ar_clutter_color_from_gdk_color (&priv->selection_color, &default_selection_color);
-      }
-#else
       GdkColor *color;
 
       if ((color = g_value_get_boxed (value)) != NULL) {
@@ -289,7 +275,6 @@ ar_style_set_property (GObject      *object,
       } else {
         priv->selection_color = default_selection_color;
       }
-#endif
       break;
     }
 
@@ -318,9 +303,6 @@ static void
 ar_style_class_init (ArStyleClass *klass)
 {
   GObjectClass *object_class = G_OBJECT_CLASS (klass);
-#ifdef HAVE_CLUTTER
-  ClutterColor color;
-#endif
 
   g_type_class_add_private (klass, sizeof (ArStylePrivate));
 
@@ -328,6 +310,19 @@ ar_style_class_init (ArStyleClass *klass)
   object_class->get_property = ar_style_get_property;
   object_class->finalize     = ar_style_finalize;
 
+  /**
+   * ArStyle:baize-color:
+   *
+   * The board baize color.
+   */
+  g_object_class_install_property
+    (object_class,
+     PROP_BAIZE_COLOR,
+     g_param_spec_boxed (AR_STYLE_PROP_BAIZE_COLOR, NULL, NULL,
+                         GDK_TYPE_COLOR,
+                         G_PARAM_READWRITE |
+                         G_PARAM_STATIC_STRINGS));
+
   g_object_class_install_property
     (object_class,
      PROP_CARD_SLOT_RATIO,
@@ -436,16 +431,6 @@ ar_style_class_init (ArStyleClass *klass)
                            G_PARAM_READWRITE |
                            G_PARAM_STATIC_STRINGS));
 
-#ifndef HAVE_CLUTTER
-  g_object_class_install_property
-    (object_class,
-     PROP_PIXBUF_DRAWING,
-     g_param_spec_boolean (AR_STYLE_PROP_PIXBUF_DRAWING, NULL, NULL,
-                           DEFAULT_PIXBUF_DRAWING,
-                           G_PARAM_READWRITE |
-                           G_PARAM_STATIC_STRINGS));
-#endif /* !HAVE_CLUTTER */
-
   g_object_class_install_property
     (object_class,
      PROP_RTL,
@@ -454,16 +439,6 @@ ar_style_class_init (ArStyleClass *klass)
                            G_PARAM_READWRITE |
                            G_PARAM_STATIC_STRINGS));
 
-#ifdef HAVE_CLUTTER
-  _ar_clutter_color_from_gdk_color (&color, &default_selection_color);
-  g_object_class_install_property
-    (object_class,
-     PROP_SELECTION_COLOR,
-     clutter_param_spec_color (AR_STYLE_PROP_SELECTION_COLOR, NULL, NULL,
-                               &color,
-                               G_PARAM_READWRITE |
-                               G_PARAM_STATIC_STRINGS));
-#else
   g_object_class_install_property
     (object_class,
      PROP_SELECTION_COLOR,
@@ -471,7 +446,6 @@ ar_style_class_init (ArStyleClass *klass)
                          GDK_TYPE_COLOR,
                          G_PARAM_READWRITE |
                          G_PARAM_STATIC_STRINGS));
-#endif /* HAVE_CLUTTER */
 
   /**
    * ArStyle:show-tooltips:
@@ -510,20 +484,6 @@ ar_style_class_init (ArStyleClass *klass)
 
 /* private API */
 
-#ifdef HAVE_CLUTTER
-
-void
-_ar_clutter_color_from_gdk_color (ClutterColor *clutter_color,
-                                  const GdkColor *gdk_color)
-{
-  clutter_color->red   = gdk_color->red   >> 8;
-  clutter_color->green = gdk_color->green >> 8;
-  clutter_color->blue  = gdk_color->blue  >> 8;
-  clutter_color->alpha = 0xff;
-}
-
-#endif /* HAVE_CLUTTER */
-
 /* public API */
 
 /**
@@ -845,17 +805,28 @@ ar_style_get_card_step (ArStyle *style)
  */
 void
 ar_style_get_selection_color (ArStyle *style,
-#ifdef HAVE_CLUTTER
-                              ClutterColor * const color)
-#else
                               GdkColor * const color)
-#endif
 {
   ArStylePrivate *priv = style->priv;
 
   *color = priv->selection_color;
 }
 
+/**
+ * ar_style_get_baize_color:
+ * @style: an #ArStyle
+ * @color: location to store the color
+ *
+ */
+void
+ar_style_get_baize_color (ArStyle *style,
+                               GdkColor * const color)
+{
+  ArStylePrivate *priv = style->priv;
+
+  *color = priv->baize_color;
+}
+
 /**
  * ar_style_check_dnd_drag_threshold:
  * @style:
@@ -885,7 +856,6 @@ ar_style_check_dnd_drag_threshold (ArStyle *style,
           ABS (y2 - y1) > priv->dnd_drag_threshold);
 }
 
-#ifndef HAVE_CLUTTER
 /**
  * ar_style_get_pixbuf_drawing:
  * @style:
@@ -899,5 +869,3 @@ ar_style_get_pixbuf_drawing (ArStyle *style)
 
   return priv->pixbuf_drawing;
 }
-
-#endif /* !HAVE_CLUTTER */
