@@ -196,11 +196,7 @@ about_cb (GtkAction * action, gpointer data)
   gchar *license = games_get_license (_("Nibbles"));
 
   gtk_show_about_dialog (GTK_WINDOW (window),
-#if GTK_CHECK_VERSION (2, 11, 0)
        "program-name", _("Nibbles"),
-#else
-       "name", _("Nibbles"),
-#endif
        "version", VERSION,
        "copyright",
        "Copyright \xc2\xa9 1999-2008 Sean MacIsaac, Ian Peters, Andreas Røsdal"
@@ -249,7 +245,7 @@ configure_event_cb (GtkWidget *widget, GdkEventConfigure *event, gpointer data)
 
   clutter_actor_set_size (CLUTTER_ACTOR (stage),
                           BOARDWIDTH * tilesize,
-                          BOARDWIDTH * tilesize);
+                          BOARDHEIGHT * tilesize);
   if (game_running ()) {
     if (board) {
       gnibbles_board_rescale (board, tilesize);
@@ -876,6 +872,7 @@ render_logo (void)
   PangoFontDescription *pfd;
   PangoLayout *layout;
   PangoContext *context;
+  GError *error = NULL;
 
   gchar *nibbles = _("Nibbles");
   /* Translators: This string will be included in the intro screen, so don't make sure it fits! */
@@ -887,7 +884,8 @@ render_logo (void)
   if (!logo_pixmap)
     gnibbles_load_logo (properties->tilesize);
 
-  image = gtk_clutter_texture_new_from_pixbuf (logo_pixmap);
+  image = gtk_clutter_texture_new ();
+  gtk_clutter_texture_set_from_pixbuf (GTK_CLUTTER_TEXTURE (image), logo_pixmap, &error);
 
   stage_w = board->width * properties->tilesize;
   stage_h = board->height * properties->tilesize;
@@ -1006,13 +1004,22 @@ main (int argc, char **argv)
   setgid_io_init ();
 #endif
 
-  gtk_clutter_init (&argc, &argv);
+  g_set_application_name (_("Nibbles"));
+
+  if (gtk_clutter_init (&argc, &argv) != CLUTTER_INIT_SUCCESS) {
+    GtkWidget *dialog = gtk_message_dialog_new (NULL,
+                                                GTK_DIALOG_MODAL,
+                                                GTK_MESSAGE_ERROR,
+                                                GTK_BUTTONS_NONE,
+                                                "%s", "Unable to initialize Clutter.");
+    gtk_window_set_title (GTK_WINDOW (dialog), g_get_application_name ());
+    gtk_dialog_run (GTK_DIALOG (dialog));
+    gtk_widget_destroy (dialog);
+    exit (1);
+  }
+
   context = g_option_context_new (NULL);
-
-#if GLIB_CHECK_VERSION (2, 12, 0)
   g_option_context_set_translation_domain (context, GETTEXT_PACKAGE);
-#endif
-
   g_option_context_add_group (context, gtk_get_option_group (TRUE));
 
   retval = g_option_context_parse (context, &argc, &argv, &error);
@@ -1023,8 +1030,6 @@ main (int argc, char **argv)
     exit (1);
   }
 
-  g_set_application_name (_("Nibbles"));
-
   gtk_window_set_default_icon_name ("gnome-gnibbles");
   srand (time (NULL));
 
