@@ -610,7 +610,6 @@ you_won (void)
 {
   gint pos;
   time_t seconds;
-  GamesScoreValue score;
   static GtkWidget *dialog = NULL;
   gchar *message;
 
@@ -618,9 +617,7 @@ you_won (void)
 
   seconds = games_clock_get_seconds (GAMES_CLOCK (chrono));
 
-  score.time_double = (seconds / 60) * 1.0 + (seconds % 60) / 100.0;
-
-  pos = games_scores_add_score (highscores, score);
+  pos = games_scores_add_time_score (highscores, (seconds / 60) * 1.0 + (seconds % 60) / 100.0);
   update_menu_sensitivities ();
   if (pos > 0) {
     if (dialog) {
@@ -898,11 +895,7 @@ about_callback (void)
   gchar *license = games_get_license (_("Mahjongg"));
 
   gtk_show_about_dialog (GTK_WINDOW (window),
-#if GTK_CHECK_VERSION (2, 11, 0)
                          "program-name", _("Mahjongg"),
-#else
-                         "name", _("Mahjongg"),
-#endif
 			 "version", VERSION,
 			 "comments",
 			 _("A matching game played with Mahjongg tiles.\n\nMahjongg is a part of GNOME Games."),
@@ -1353,10 +1346,7 @@ main (int argc, char *argv[])
 #endif
 
   context = g_option_context_new (NULL);
-#if GLIB_CHECK_VERSION (2, 12, 0)
   g_option_context_set_translation_domain (context, GETTEXT_PACKAGE);
-#endif
-
   g_option_context_add_group (context, gtk_get_option_group (TRUE));
 
   retval = g_option_context_parse (context, &argc, &argv, &error);
